@@ -2,7 +2,6 @@ from .base import Strategy, Guard, get_user
 from .jwt import JWTStrategy
 from .api_key import APIKeyStrategy
 from .slack import SlackStrategy
-from .cfg import Configuration
 from .error import AuthenticationError
 
 __all__ = [
@@ -12,6 +11,5 @@ __all__ = [
     JWTStrategy,
     APIKeyStrategy,
     SlackStrategy,
-    Configuration,
     AuthenticationError
 ]
\ No newline at end of file
